pub enum DelayFunction {
Constant,
Exponential,
Fibonacci,
}Expand description
Specifies the function that is used to calculate subsequent reschedule delays.
Variants
Constant
The delay between reschedule attempts stays at the Delay value.
Exponential
The delay between reschedule attempts doubles.
Fibonacci
The delay between reschedule attempts is calculated by adding the two most recent delays applied.