pub enum DriverConfig {
Bool(bool),
String(String),
Int(i64),
Float(f64),
Vector(Vec<DriverConfig>),
Map(HashMap<String, DriverConfig>),
}Expand description
A map of key-value configuration passed into the driver to start the task. The details of configurations are specific to each driver.
Variants
Bool(bool)
A boolean value.
String(String)
A string value.
Int(i64)
An integer value.
Float(f64)
A float value.
Vector(Vec<DriverConfig>)
An array/vector value.
Map(HashMap<String, DriverConfig>)
A map value to represent arbitrarily nested key-values.