pub struct Affinity {
pub l_target: Option<String>,
pub r_target: Option<String>,
pub operand: AffinityOperator,
pub weight: i8,
}Expand description
A representation of placement preferences on nodes where a job can be run.
Fields
l_target: Option<String>Specifies the attribute to examine for the affinity.
r_target: Option<String>specifies the value to compare the attribute against. This can be a literal value, another attribute or a regular expression if the Operator is in “regexp” mode.
operand: AffinityOperatorSpecifies the test to be performed on the two targets. See also AffinityOperator
weight: i8A non zero weight, valid values are from -100 to 100. Used to express relative preference when there is more than one affinity.