pub struct CheckRestart {
pub limit: u32,
pub grace: Duration,
pub ignore_warnings: bool,
}Expand description
CheckRestart is an object which enables restarting of tasks based upon Consul health checks.
Fields
limit: u32The number of unhealthy checks allowed before the service is restarted. Defaults to 0 which disables health-based restarts.
grace: DurationThe duration to wait after a task starts or restarts before counting unhealthy checks count against the limit. Defaults to 1 second.
ignore_warnings: boolTreat checks that are warning as passing. Defaults to false which means warnings are considered unhealthy.