pub struct Children {
pub pending: u32,
pub running: u32,
pub dead: u32,
}Expand description
The instance summary of the children for the current job.
Fields
pending: u32The number of instances in pending for the current job.
running: u32The number of instances running for the current job.
dead: u32The number of dead instances for the current job.