pub struct CreateJobPlanResponse {
pub job_modify_index: u64,
pub annotations: PlanAnnotations,
pub diff: JobDiff,
pub next_periodic_launch: Option<Duration>,
pub warnings: String,
}Expand description
The request to create the plan to create or update a job.
Fields
job_modify_index: u64The modify index of the job.
annotations: PlanAnnotationsAnnotations for the generated plan.
diff: JobDiffThe difference report for the deployed job.
next_periodic_launch: Option<Duration>The next launch of this periodic job, if it is one.
warnings: StringContains any warnings about the given job. These may include deprecation warnings.