pub struct DispatchPayload {
pub file: String,
}Expand description
Configures the task to have access to dispatch payloads.
Fields
file: StringSpecifies the file name to write the content of dispatch payload to. The file is written relative to the task’s local directory.