pub struct JobRegisterResponse {
pub eval_id: String,
pub eval_create_index: u64,
pub job_modify_index: u64,
}Expand description
The response from nomad for a create or update a job request. See also list_jobs
Fields
eval_id: StringThe ID of the evaluation for this request.
eval_create_index: u64Specifies the index of the current evaluation for this job.
job_modify_index: u64Specifies the job_modify_index to enforce the current job at.