pub struct Lifecycle {
pub hook: String,
pub sidecar: bool,
}Expand description
The lifecycle block in Nomad is used to define the order in which tasks are executed within a task group. Main tasks are those without a lifecycle block, and tasks with lifecycle hooks specify their execution timing relative to the main tasks. For more information See https://developer.hashicorp.com/nomad/docs/job-specification/lifecycle for more details.
Fields
hook: StringSpecifies when a task should be run within the lifecycle of a group.
sidecar: boolControls whether a task is ephemeral or long-lived within the task group. If a lifecycle task is ephemeral (sidecar = false), the task will not be restarted after it completes successfully. If a lifecycle task is long-lived (sidecar = true) and terminates, it will be restarted as long as the allocation is running.