pub struct LogConfig {
pub max_files: u32,
pub max_file_size_in_mb: u32,
}Expand description
The LogConfig object configures the log rotation policy for a task’s stdout and stderr
Fields
max_files: u32The maximum number of rotated files Nomad will retain for stdout and stderr, each tracked individually.
max_file_size_in_mb: u32The size of each rotated file. The size is specified in MB.