pub struct MigrateStrategy {
pub max_parallel: u32,
pub health_check: HealthCheck,
pub min_healthy_time: Duration,
pub healthy_deadline: Duration,
}Expand description
Specifies a migration strategy to be applied during node drains.
Fields
max_parallel: u32Specifies how many allocations may be migrated at once. Defaults to 1.
health_check: HealthCheckIndicates how task health should be determined: either via Consul health checks or whether the task was able to run successfully. See also HealthCheck
min_healthy_time: DurationSpecifies duration a task must be considered healthy before the migration is considered healthy. Defaults to 10 seconds.
healthy_deadline: DurationSpecifies duration a task must become healthy within before it is considered unhealthy. Defaults to 5 minutes.