pub struct ParameterizedJobConfig {
pub meta_optional: Vec<String>,
pub meta_required: Vec<String>,
pub payload: PayloadRequirement,
}Expand description
Represents a parameterized job that can be dispatched with a custom payload.
Fields
meta_optional: Vec<String>Specifies the set of metadata keys that may be provided when dispatching against the job as a string array.
meta_required: Vec<String>Specifies the set of metadata keys that must be provided when dispatching against the job as a string array.
payload: PayloadRequirementSpecifies the requirement of providing a payload when dispatching against the parameterized job. The default value is PayloadRequirement::Optional.