PeriodicConfig

Struct PeriodicConfig 

pub struct PeriodicConfig {
    pub enabled: bool,
    pub time_zone: String,
    pub spec_type: SpecType,
    pub spec: String,
    pub prohibit_overlap: bool,
}
Specifies that the job can be scheduled at fixed times, dates or intervals. The periodic expression is always evaluated in the UTC timezone to ensure consistent evaluation when Nomad Servers span multiple time zones.

Fields

enabled: bool

Enabled determines whether the periodic job will spawn child jobs.

time_zone: String

Specifies the time zone to evaluate the next launch interval against. This is useful when wanting to account for day light savings in various time zones. The time zone must be parsable by Golang’s LoadLocation. The default is UTC.

spec_type: SpecType

SpecType determines how Nomad is going to interpret the periodic expression. SpecType::cron is the only supported SpecType currently.

spec: String

A cron expression configuring the interval the job is launched at. Supports predefined expressions such as “@daily” and “@weekly”

prohibit_overlap: bool

ProhibitOverlap can be set to true to enforce that the periodic job doesn’t spawn a new instance of the job if any of the previous jobs are still running. It is defaulted to false.