pub struct Port {
pub value: u32,
pub label: String,
pub to: u32,
}Expand description
The port configuration for a Network.
Fields
value: u32The port number for static/reserved ports. If the port is dynamic, then this attribute is ignored
label: StringThe label to annotate a port so that it can be referred in the service discovery block or environment variables.
to: u32The static port this network points to on the driver.