Scaling

Struct Scaling 

pub struct Scaling {
    pub min: Option<u32>,
    pub max: u32,
    pub enabled: bool,
    pub policy: HashMap<String, DriverConfig>,
}
Scaling policies allow operators to attach autoscaling configuration to a task group. This information can be queried by external autoscalers.

Fields

min: Option<u32>

The minimum allowable count for the task group. This is optional; if absent, the default is the Count specified in the task group. Attempts to set the task group Count below Min will result in a 400 error during job registration.

max: u32

The maximum allowable count for the task group. This is required if a scaling policy is provided. This must be larger than Min. Attempts to set the task group Count above Max wil result in a 400 error during job registration.

enabled: bool

An optional boolean (default: true). This indicates to the autoscaler that this scaling policy should be ignored. It is intended to allow autoscaling to be temporarily disabled for a task group.

policy: HashMap<String, DriverConfig>

An optional JSON block. This is opaque to Nomad; see the documentation for the external autoscaler.