pub struct Spread {
pub attribute: String,
pub target: Vec<SpreadTarget>,
pub weight: u8,
}Expand description
Spread allow operators to target specific percentages of allocations based on any node attribute or metadata.
Fields
attribute: StringSpecifies the attribute to examine for the spread.
target: Vec<SpreadTarget>Specifies a list of attribute values and percentages. This is an optional field, when left empty Nomad will evenly spread allocations across values of the attribute.
weight: u8A non zero weight, valid values are from -100 to 100. Used to express relative preference when there is more than one spread or affinity.