pub struct SummaryInfo {
pub queued: u32,
pub complete: u32,
pub failed: u32,
pub running: u32,
pub starting: u32,
pub lost: u32,
}Expand description
The summary for instances of a particular job.
Fields
queued: u32The number of instances of this job that have been queued.
complete: u32The number of instances of this job that have completed.
failed: u32The number of instances of this job that have failed.
running: u32The number of instances of this job that are running.
starting: u32The number of instances of this job that are starting.
lost: u32The number of instances of this job that have been lost.