UpdateStrategy

Struct UpdateStrategy 

pub struct UpdateStrategy {
    pub max_parallel: u32,
    pub health_check: HealthCheck,
    pub min_healthy_time: Duration,
    pub healthy_deadline: Duration,
    pub progress_deadline: Duration,
    pub auto_revert: bool,
    pub canary: u32,
    pub auto_promote: bool,
    pub stagger: Duration,
}
Specifies the task group update strategy. When omitted, rolling updates are disabled. The update stanza can be specified at the job or task group level. When specified at the job, the update stanza is inherited by all task groups. When specified in both the job and in a task group, the stanzas are merged with the task group’s taking precedence.

Fields

max_parallel: u32

Specifies the number of tasks that can be updated at the same time. Defaults to 1.

health_check: HealthCheck

Specifies the mechanism in which allocations health is determined. See also HealthCheck

min_healthy_time: Duration

Specifies the minimum time the allocation must be in the healthy state before it is marked as healthy and unblocks further allocations from being updated. Defaults to 10 seconds.

healthy_deadline: Duration

Specifies the deadline in which the allocation must be marked as healthy after which the allocation is automatically transitioned to unhealthy. Defaults to 5 minutes.

progress_deadline: Duration

Specifies the deadline in which an allocation must be marked as healthy. The deadline begins when the first allocation for the deployment is created and is reset whenever an allocation as part of the deployment transitions to a healthy state. If no allocation transitions to the healthy state before the progress deadline, the deployment is marked as failed. If the progress_deadline is set to 0, the first allocation to be marked as unhealthy causes the deployment to fail. Defaults to 10 minutes.

auto_revert: bool

Specifies if the job should auto-revert to the last stable job on deployment failure. A job is marked as stable if all the allocations as part of its deployment were marked healthy. Defaults to false.

canary: u32

Specifies that changes to the job that would result in destructive updates should create the specified number of canaries without stopping any previous allocations. Once the operator determines the canaries are healthy, they can be promoted which unblocks a rolling update of the remaining allocations at a rate of max_parallel. Defaults to 0.

auto_promote: bool

specifies if the job should automatically promote to the new deployment if all canaries become healthy. Defaults to false.

stagger: Duration

Specifies the delay between migrating allocations off nodes marked for draining. Defaults to 30 seconds.