pub enum AddressMode {
None,
Auto,
Driver,
Host,
}Expand description
Specifies what address (host or driver-specific) this service should advertise.
Variants
None
Can be unspecified for ConsulCheck.
Auto
Allows the driver to determine whether the host or driver address should be used. Defaults to host and only implemented by Docker. If you use a Docker network plugin such as weave, Docker will automatically use its address.
Driver
Use the IP specified by the driver, and the port specified in a port map. A numeric port may be specified since port maps aren’t required by all network plugins. Useful for advertising SDN and overlay network addresses. Task will fail if driver network cannot be determined. Only implemented for Docker and rkt.
Host
Use the host IP and port.