pub enum HealthCheck {
Checks,
TaskStates,
Manual,
}Expand description
Indicates how task health should be determined: either via Consul health checks or whether the task was able to run successfully.
Variants
Checks
Specifies that the allocation should be considered healthy when all of its tasks are running and their associated checks are healthy, and unhealthy if any of the tasks fail or not all checks become healthy. This is a superset of “task_states” mode.
TaskStates
Specifies that the allocation should be considered healthy when all its tasks are running and unhealthy if tasks fail.
Manual
Specifies that Nomad should not automatically determine health and that the operator will specify allocation health using the HTTP API.