pub enum JobType {
Service,
Batch,
System,
}Expand description
Specifies the job type and switches which scheduler is used. Nomad provides the service, system and batch schedulers, and defaults to service
Variants
Service
The service scheduler is designed for scheduling long lived services that should never go down. As such, the service scheduler ranks a large portion of the nodes that meet the job’s constraints and selects the optimal node to place a task group on.
Batch
The system scheduler is used to register jobs that should be run on all clients that meet the job’s constraints. The system scheduler is also invoked when clients join the cluster or transition into the ready state. This means that all registered system jobs will be re-evaluated and their tasks will be placed on the newly available nodes if the constraints are met.
System
Batch jobs are much less sensitive to short term performance fluctuations and are short lived, finishing in a few minutes to a few days. Although the batch scheduler is very similar to the service scheduler, it makes certain optimizations for the batch workload.