pub struct ConciseJob {Show 16 fields
pub id: String,
pub parent_id: Option<String>,
pub job_type: JobType,
pub name: String,
pub datacenters: Vec<String>,
pub priority: u8,
pub periodic: bool,
pub parameterized_job: bool,
pub stop: bool,
pub status: Option<JobStatus>,
pub status_description: Option<String>,
pub create_index: u64,
pub modify_index: u64,
pub job_modify_index: u64,
pub submit_time: i64,
pub job_summary: JobSummary,
}Expand description
Represents a single job summary as part of the Nomad::list_jobs api.
Fields
id: StringThe ID of the nomad job.
parent_id: Option<String>The job ID of the parent nomad job.
job_type: JobTypeThe type of the nomad job. See JobType
name: StringThe name of the nomad job.
datacenters: Vec<String>The nomad datacenters for this nomad job.
priority: u8The priority of the nomad job. Can be between 1 and 100.
periodic: boolWhether the job is scheduled at a fixed date/time/interval.
parameterized_job: boolWhether the job is dispatched using a custom payload.
stop: boolWhether the job is stopped.
status: Option<JobStatus>The status of the job.
status_description: Option<String>The status description of the job.
create_index: u64The create index.
modify_index: u64The modify index.
job_modify_index: u64The modify index of the job.
submit_time: i64The time the job was submitted as a unix timestamp.
job_summary: JobSummaryThe summary of the job. See also JobSummary