pub struct ConsulCheck {Show 19 fields
pub check_type: CheckType,
pub name: String,
pub command: String,
pub args: Vec<String>,
pub path: Option<String>,
pub protocol: Option<Protocol>,
pub expose: bool,
pub address_mode: AddressMode,
pub port_label: String,
pub interval: Duration,
pub timeout: Duration,
pub initial_status: Option<String>,
pub tls_skip_verify: bool,
pub method: HttpMethod,
pub header: Option<HashMap<String, Vec<String>>>,
pub grpc_service: String,
pub grpc_use_tls: bool,
pub task_name: String,
pub check_restart: CheckRestart,
}Expand description
Checks define health checks associated with the service. Nomad supports the script, http and tcp Consul Checks.
Fields
check_type: CheckTypeThis indicates the check types supported by Nomad.
name: StringThe name of the health check.
command: StringThe command to execute.
args: Vec<String>The arguments to provide the command.
path: Option<String>The path or route to use.
protocol: Option<Protocol>The protocol to use. See also Protocol
expose: boolWhether to expose the check.
address_mode: AddressModeThe address mode to use. See also AddressMode
port_label: StringThe port label to use.
interval: DurationThis indicates the frequency of the health checks that Consul will perform.
timeout: DurationThis indicates how long Consul will wait for a health check query to succeed.
initial_status: Option<String>The initial status of the check.
tls_skip_verify: boolIf true, Consul will not attempt to verify the certificate when performing HTTPS checks. Requires Consul >= 0.7.2.
method: HttpMethodThe HTTP method to use for HTTP checks.
Defaults to HttpMethod::GET.
header: Option<HashMap<String, Vec<String>>>Headers for HTTP checks. Headers will be written once for each value.
grpc_service: StringThe grpc healthcheck.
grpc_use_tls: boolWhether the grpc healthcheck uses TLS.
task_name: StringThe name of the task for the check.
check_restart: CheckRestartCheckRestart is an object which enables restarting of tasks based upon Consul health checks.