pub struct RestartPolicy {
pub attempts: u32,
pub interval: Duration,
pub delay: Duration,
pub mode: RestartMode,
}Expand description
Specifies the restart policy in case of task failure.
Fields
attempts: u32Attempts is the number of restarts allowed in an Interval. Defaults to 1.
interval: DurationThe Interval begins when the first task starts and ensures that only Attempts number of restarts happens within it. If more than Attempts number of failures happen, behavior is controlled by Mode. Defaults to 30 minutes.
delay: DurationA duration to wait before restarting a task. A random jitter of up to 25% is added to the delay. Defaults to 15 seconds.
mode: RestartModeMode controls the behavior when the task fails more than Attempts times in an Interval. See also RestartMode