The minimum allowable count for the task group.
This is optional; if absent, the default is the Count specified in the task group.
Attempts to set the task group Count below Min will result in a 400 error during job registration.
The maximum allowable count for the task group.
This is required if a scaling policy is provided.
This must be larger than Min.
Attempts to set the task group Count above Max wil result in a 400 error during job registration.
An optional boolean (default: true).
This indicates to the autoscaler that this scaling policy should be ignored.
It is intended to allow autoscaling to be temporarily disabled for a task group.